Austro Simulator
================

Warning
-------

This software version currently *alpha*. Expect occuring some issues, crashes,
etc.

What is?
--------

Austro Simulator is a CPU simulator resembling Intel 8086, except for some
differences.

The software is developed with the Python programmming language and Qt UI
toolkit.

TODO

How to install
--------------

TODO

How to use
----------

TODO
